import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("program", "0131_remove_episodes_unassigned_to_shows"),
    ]

    operations = [
        # make show required
        migrations.AlterField(
            model_name="episode",
            name="show",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="episodes",
                to="program.show",
            ),
        ),
        # Cleanup related names, help texts and permissions.
        migrations.AlterField(
            model_name="episode",
            name="image",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="episodes",
                to="program.image",
            ),
        ),
        migrations.AlterField(
            model_name="episode",
            name="contributors",
            field=models.ManyToManyField(
                help_text="Profile IDs that contributed to this episode.",
                related_name="episodes",
                to="program.profile",
            ),
        ),
        migrations.AlterField(
            model_name="episode",
            name="summary",
            field=models.TextField(blank=True, help_text="Summary of this episode."),
        ),
        migrations.AlterField(
            model_name="episode",
            name="title",
            field=models.CharField(
                blank=True, default="", help_text="Title of this episode.", max_length=128
            ),
        ),
        migrations.AlterField(
            model_name="episode",
            name="content",
            field=models.TextField(blank=True, help_text="Textual content of this episode."),
        ),
        migrations.AlterModelOptions(
            name="episode",
            options={
                "permissions": [
                    ("edit__episode__cba_id", "Can edit CBA id field"),
                    ("edit__episode__content", "Can edit content field"),
                    ("edit__episode__contributors", "Can edit contributors field"),
                    ("edit__episode__image", "Can edit image field"),
                    ("edit__episode__languages", "Can edit languages field"),
                    ("edit__episode__links", "Can edit links field"),
                    ("edit__episode__playlist", "Can edit playlist field"),
                    ("edit__episode__summary", "Can edit summary field"),
                    ("edit__episode__tags", "Can edit tags field"),
                    ("edit__episode__title", "Can edit title field"),
                    ("edit__episode__topics", "Can edit topics field"),
                    ("edit__episode__memo", "Can edit memo field"),
                    ("edit__episode__media", "Can edit media."),
                    ("create_episode", "Can create episode"),
                    ("update_episode", "Can update episode"),
                ]
            },
        ),
        migrations.AlterModelOptions(
            name="timeslot",
            options={
                "ordering": ("start", "end"),
                "permissions": [
                    ("update_timeslot", "Can update timeslot"),
                ],
            },
        ),
        # Rename references
        migrations.RenameModel(
            "NoteLink",
            "EpisodeLink",
        ),
        migrations.RenameField(
            model_name="episodelink",
            old_name="note",
            new_name="episode",
        ),
        migrations.RenameField(
            model_name="radiosettings",
            old_name="note_image_aspect_ratio",
            new_name="episode_image_aspect_ratio",
        ),
        migrations.RenameField(
            model_name="radiosettings",
            old_name="note_image_shape",
            new_name="episode_image_shape",
        ),
    ]
